@@ -7,10 +7,13 @@ import re
 import sys
 from urllib import request, parse
 
+__version__ = "0.1.3"
+
 try:
     proj_info = json.loads(open('you-get.json').read())
 except:
-    proj_info = {'version': ''}
+    import you_get
+    proj_info = {'version': __version__}
 
 force = False
 
@@ -158,7 +161,10 @@ def url_save(url, filepath, bar, refer = None, is_part = False):
             headers['Referer'] = refer
         
         response = request.urlopen(request.Request(url, headers = headers), None)
-        assert file_size == received + int(response.headers['content-length'])
+        
+        if file_size != received + int(response.headers['content-length']):
+            received = 0
+            open_mode = 'wb'
         
         with open(temp_filepath, open_mode) as output:
             while True:
@@ -272,6 +278,7 @@ def download_urls(urls, title, ext, total_size, output_dir = '.', refer = None,
     if total_size:
         if not force and os.path.exists(filepath) and os.path.getsize(filepath) >= total_size * 0.9:
             print('Skipping %s: file already exists' % tr(filepath))
+            print()
             return
         bar = SimpleProgressBar(total_size, len(urls))
     else:
@@ -294,6 +301,7 @@ def download_urls(urls, title, ext, total_size, output_dir = '.', refer = None,
             url_save(url, filepath, bar, refer = refer, is_part = True)
         bar.done()
         if not merge:
+            print()
             return
         if ext == 'flv':
             from .processor.merge_flv import concat_flvs
@@ -307,6 +315,8 @@ def download_urls(urls, title, ext, total_size, output_dir = '.', refer = None,
                 os.remove(flv)
         else:
             print("Can't merge %s files" % ext)
+    
+    print()
 
 def playlist_not_supported(name):
     def f(*args, **kwargs):
