@@ -16,10 +16,11 @@ def url_to_module(url):
     
     k = r1(r'([^.]+)', domain)
     downloads = {
-        'youtube': youtube,
-        'youku': youku,
-        'yinyuetai': yinyuetai,
+        'sohu': sohu,
         'tudou': tudou,
+        'yinyuetai': yinyuetai,
+        'youku': youku,
+        'youtube': youtube,
         #TODO:
         # 'acfun': acfun,
         # 'bilibili': bilibili,
@@ -29,7 +30,6 @@ def url_to_module(url):
         # 'ku6': ku6,
         # 'pptv': pptv,
         # 'iqiyi': iqiyi,
-        # 'sohu': sohu,
         # '56': w56,
         # 'cntv': cntv,
     }
@@ -47,4 +47,8 @@ def any_download_playlist(url, output_dir = '.', merge = True, info_only = False
     m.download_playlist(url, output_dir = output_dir, merge = merge, info_only = info_only)
 
 def main():
-    script_main('you-get', any_download, any_download_playlist)
+    import sys
+    try:
+        script_main('you-get', any_download, any_download_playlist)
+    except KeyboardInterrupt:
+        sys.exit(1)
